@@ -86,7 +86,7 @@ describe 'apt_key' do
         EOS
 
         # Install the key first
-        shell("apt-key adv --keyserver keyserver.ubuntu.com \
+        shell("apt-key adv --keyserver hkps.pool.sks-keyservers.net \
               --recv-keys #{CENTOS_GPG_KEY_FINGERPRINT}")
         shell(CENTOS_KEY_CHECK_COMMAND)
 
@@ -97,7 +97,7 @@ describe 'apt_key' do
         shell(CENTOS_KEY_CHECK_COMMAND,
               :acceptable_exit_codes => [1])
 
-        shell("apt-key adv --keyserver keyserver.ubuntu.com \
+        shell("apt-key adv --keyserver hkps.pool.sks-keyservers.net \
               --recv-keys #{CENTOS_GPG_KEY_FINGERPRINT}")
       end
     end
@@ -112,7 +112,7 @@ describe 'apt_key' do
         EOS
 
         # Install the key first
-        shell("apt-key adv --keyserver keyserver.ubuntu.com \
+        shell("apt-key adv --keyserver hkps.pool.sks-keyservers.net \
               --recv-keys #{PUPPETLABS_GPG_KEY_LONG_ID}")
         shell(PUPPETLABS_KEY_CHECK_COMMAND)
 
@@ -401,13 +401,13 @@ ZTQcCD53HcBLvKX6RJ4ByYawKaQqMa27WK/YWVmFXqVDVk12iKrQW6zktDdGInnD
   end
 
   describe 'server =>' do
-    context 'pgp.mit.edu' do
+    context 'hkps.pool.sks-keyservers.net' do
       it 'works' do
         pp = <<-EOS
         apt_key { 'puppetlabs':
           id     => '#{PUPPETLABS_GPG_KEY_LONG_ID}',
           ensure => 'present',
-          server => 'pgp.mit.edu',
+          server => 'hkps.pool.sks-keyservers.net',
         }
         EOS
 
@@ -417,13 +417,13 @@ ZTQcCD53HcBLvKX6RJ4ByYawKaQqMa27WK/YWVmFXqVDVk12iKrQW6zktDdGInnD
       end
     end
 
-    context 'hkp://pgp.mit.edu:80' do
+    context 'hkp://hkps.pool.sks-keyservers.net:80' do
       it 'works' do
         pp = <<-EOS
         apt_key { 'puppetlabs':
           id     => '#{PUPPETLABS_GPG_KEY_FINGERPRINT}',
           ensure => 'present',
-          server => 'hkp://pgp.mit.edu:80',
+          server => 'hkp://hkps.pool.sks-keyservers.net:80',
         }
         EOS
 
@@ -684,21 +684,6 @@ ZTQcCD53HcBLvKX6RJ4ByYawKaQqMa27WK/YWVmFXqVDVk12iKrQW6zktDdGInnD
         apply_manifest(pp, :catch_failures => true)
         shell(PUPPETLABS_KEY_CHECK_COMMAND)
       end
-
-      it 'fails on invalid options' do
-        pp = <<-EOS
-        apt_key { 'puppetlabs':
-          id      => '#{PUPPETLABS_GPG_KEY_LONG_ID}',
-          ensure  => 'present',
-          options => 'this is totally bonkers',
-        }
-        EOS
-
-        shell("apt-key del #{PUPPETLABS_GPG_KEY_FINGERPRINT}", :acceptable_exit_codes => [0,1,2])
-        apply_manifest(pp, :expect_failures => true) do |r|
-          expect(r.stderr).to match(/--keyserver-options this is totally/)
-        end
-      end
     end
   end
 
