@@ -21,7 +21,7 @@ describe 'apt class' do
             'repos'    => 'main',
             'key'      => {
               'id'     => '47B320EB4C7C375AA9DAE1A01054B7A24BD6EC30',
-              'server' => 'pgp.mit.edu',
+              'server' => 'hkps.pool.sks-keyservers.net',
             },
           },
         }
